from fastapi import APIRouter, BackgroundTasks, Query

from app.controllers.equipment.ahu.supply_air_temperature_set import get_next_supply_air_temperature_set
from app.controllers.equipment.ahu.thermal_mode import get_thermal_mode
from app.controllers.equipment.fcu.on_ratio import start_on_ratio_mode
from app.controllers.equipment.pau.switch import get_switch_action
from app.models.domain.devices import DevicesInstructionsBaseResponse


router = APIRouter()


@router.get('/instructions/acatah/thermal-mode-set', response_model=DevicesInstructionsBaseResponse)
async def get_acatah_thermal_mode_set(
        project_id: str = Query(..., max_length=50, regex='^Pj', alias='projectId'),
        device_id: str = Query(..., max_length=50, regex='^Eq', alias='equipId')
):
    thermal_mode = await get_thermal_mode(project_id, device_id)

    return {
        'projectId': project_id,
        'equipId': device_id,
        'output': {
            'thermalModeSet': thermal_mode
        }
    }


@router.get('/instructions/acatah/supply-air-temperature-set', response_model=DevicesInstructionsBaseResponse)
async def get_acatah_supply_air_temperature_set(
        project_id: str = Query(..., max_length=50, regex='^Pj', alias='projectId'),
        device_id: str = Query(..., max_length=50, regex='^Eq', alias='equipId')
):
    next_supply_air_temperature_set = await get_next_supply_air_temperature_set(project_id, device_id)

    return {
        'projectId': project_id,
        'equipId': device_id,
        'output': {
            'supplyAirTemperatureSet': next_supply_air_temperature_set
        }
    }


@router.post('/on-ratio-experiment/fcu/{fcu_id}/target/{target}/period/{period}')
async def run_on_ratio_experiment(fcu_id: str, target: float, period: int, background_tasks: BackgroundTasks):
    background_tasks.add_task(start_on_ratio_mode, fcu_id, target, period)
    return {
        'fcu': fcu_id,
        'target': target,
        'period': period
    }


@router.get('/instructions/acatfu/equip-switch-set', response_model=DevicesInstructionsBaseResponse)
async def get_acatfu_equip_switch_set(
        project_id: str = Query(..., max_length=50, regex='^Pj', alias='projectId'),
        device_id: str = Query(..., max_length=50, regex='^Eq', alias='equipId')
):
    action = await get_switch_action(project_id, device_id)

    return {
        'projectId': project_id,
        'equipId': device_id,
        'output': {
            'equipSwitchSet': action
        }
    }


@router.get('/instructions/acatfu/supply-ari-temperature-set', response_model=DevicesInstructionsBaseResponse)
async def get_acatfu_supply_air_temperature_set(
        project_id: str = Query(..., max_length=50, regex='^Pj', alias='projectId'),
        device_id: str = Query(..., max_length=50, regex='^Eq', alias='equipId')
):
    pass
